﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Olap;
using Infragistics.Olap.FlatData;

namespace HierarchiesCollection
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public IEnumerable<SOHoldingUIEntity> LocalData { get; private set; }

        public MainWindow()
        {
            InitializeComponent();
            InitializeData();
            BindGrid();
        }

        private void BindGrid()
        {
            IEnumerable<FlattenHierarchy> flattenData;
            flattenData = from data in LocalData
                          from item in data.soitems
                          select new FlattenHierarchy{SoHoldingUiEntity = data, SoItem = item};

            FlatDataSource flatDataSource = new FlatDataSource()
            {
                ItemsSource = flattenData,
                Cube = DataSourceBase.GenerateInitialCube("Cube")
            };

            CubeMetadata cubeMetadata = new CubeMetadata();
            cubeMetadata.DisplayName = "Cube";
            cubeMetadata.DataTypeFullName = typeof(FlattenHierarchy).FullName;
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
            {
                SourcePropertyName = "SoHoldingUiEntity"
            });
           
            cubeMetadata.DimensionSettings.Add(new DimensionMetadata()
                                                   {
                                                       SourcePropertyName = "SoItem",
                                                       DisplayName = "Count Items",
                                                       DimensionType = DimensionType.Measure,
                                                       Aggregator = new CountAggregator()
                                                   });
            flatDataSource.CubesSettings.Add(cubeMetadata);

            HierarchyDescriptor<FlattenHierarchy> hierarchy = new HierarchyDescriptor<FlattenHierarchy>(p => p.SoHoldingUiEntity) {HierarchyName = "Group"};
            hierarchy.AddLevel(p => "All", "All");
            hierarchy.AddLevel(p => p.SoHoldingUiEntity.group_header, "Group");
            hierarchy.AddLevel(p => p.SoItem.Name, "Item");
            flatDataSource.AddHierarchyDescriptor(hierarchy);

            this.pivotGrid.DataSource = flatDataSource;
            this.dataSelector.DataSource = flatDataSource;
        }

        private void InitializeData()
        {
            LocalData = new List<SOHoldingUIEntity>
                {
                    new SOHoldingUIEntity
                        {
                            group_header = "header 1",
                            soitems =
                                new ObservableCollection<StockOptimisationStockHoldingItemEntity>
                                    {
                                        new StockOptimisationStockHoldingItemEntity {Name = "item 1", Quantity = 5},
                                        new StockOptimisationStockHoldingItemEntity {Name = "item 2", Quantity = 6},
                                        new StockOptimisationStockHoldingItemEntity {Name = "item 3", Quantity = 7}
                                    }
                        },

                        new SOHoldingUIEntity
                        {
                            group_header = "header 1",
                            soitems =
                                new ObservableCollection<StockOptimisationStockHoldingItemEntity>
                                    {
                                        new StockOptimisationStockHoldingItemEntity {Name = "item 1", Quantity = 5},
                                        new StockOptimisationStockHoldingItemEntity {Name = "item 2", Quantity = 6},
                                        new StockOptimisationStockHoldingItemEntity {Name = "item 3", Quantity = 7},
                                        new StockOptimisationStockHoldingItemEntity {Name = "item 4", Quantity = 8}
                                    }
                        }
                };
        }
    }
}
